import {
  Brightness1,
  StopCircle,
  RadioButtonUnchecked,
  HelpOutline
} from "@mui/icons-material";

export const STATUS = {
  active: "active",
  disabled: "disabled",
  alert: "alert",
  warning: "warning",
  inactive: "inactive",
  inactiveAlert: "inactive alert",
  inactiveWarning: "inactive warning"
};

export const SEVERITY = {
  info: "info",
  alert: "error",
  warning: "warning"
};

export const statusConfig = {
  [STATUS.active]: {
    title: "Active",
    icon: Brightness1
  },
  [STATUS.disabled]: {
    title: "Disabled",
    icon: StopCircle
  },
  [STATUS.alert]: {
    title: "Active with alert(s)",
    icon: Brightness1
  },
  [STATUS.warning]: {
    title: "Active with warning(s)",
    icon: Brightness1
  },
  [STATUS.inactive]: {
    title: "Inactive",
    icon: RadioButtonUnchecked
  },
  [STATUS.inactiveAlert]: {
    title: "Inactive with alert(s)",
    icon: RadioButtonUnchecked
  },
  [STATUS.inactiveWarning]: {
    title: "Inactive with warning(s)",
    icon: RadioButtonUnchecked
  },
  null: {
    title: "Unknown",
    icon: HelpOutline
  }
};

export const getStatus = (state, alert) => {
  let { isActive } = state;
  const alertSeverity = alert?.alertSeverity?.toLowerCase();

  if (
    isActive &&
    (alertSeverity === undefined || alertSeverity === SEVERITY.info)
  ) {
    // Active status / running
    return STATUS.active;
  } else if (
    isActive === false &&
    (alertSeverity === undefined || alertSeverity === SEVERITY.info)
  ) {
    // stopped/paused
    return STATUS.disabled;
  } else if (
    isActive &&
    alertSeverity !== undefined &&
    alertSeverity === SEVERITY.alert
  ) {
    // error
    return STATUS.alert;
  } else if (
    isActive &&
    alertSeverity !== undefined &&
    alertSeverity === SEVERITY.warning
  ) {
    // warning
    return STATUS.warning;
  } else if (
    (!isActive || isActive === null) &&
    (alertSeverity === undefined || alertSeverity === SEVERITY.info)
  ) {
    // Inactive status
    return STATUS.inactive;
  } else if (
    (!isActive || isActive === null) &&
    alertSeverity === SEVERITY.alert
  ) {
    // inactive with warning/error
    return STATUS.inactiveAlert;
  } else if (
    (!isActive || isActive === null) &&
    alertSeverity === SEVERITY.warning
  ) {
    return STATUS.inactiveWarning;
  } else {
    // unknown fallback state
    return null;
  }
};
