import { useTheme } from "@mui/material";
import Popover from "../common/Popover";
import {
  StatusBadge,
  StatusIcon,
  STATUS,
  StatusPopoverContent,
  statusConfig
} from "../common/Status";
import { getHostStatusInfo } from "./HostStatusData";

export function HostStatusIcon({ hostStatus, hideAlerts = false }) {
  const theme = useTheme();

  let { alerts } = hostStatus;
  let hostStatusStatus = getHostStatusInfo(hostStatus);

  const displayBadge =
    !hideAlerts &&
    (hostStatusStatus === STATUS.alert ||
      hostStatusStatus === STATUS.warning ||
      hostStatusStatus === STATUS.inactiveAlert ||
      hostStatusStatus === STATUS.inactiveWarning);

  return (
    <Popover
      id={`host-status-popover-${hostStatus.hostId}`}
      renderOwningComponent={({
        ariaOwns,
        ariaHasPopup,
        handlePopoverOpen,
        handlePopoverClose
      }) => (
        <div
          aria-owns={ariaOwns}
          aria-haspopup={ariaHasPopup}
          onMouseEnter={handlePopoverOpen}
          onMouseLeave={handlePopoverClose}
          style={{ color: theme.palette.status.icons }}
        >
          {displayBadge ? (
            <StatusBadge
              status={hostStatusStatus}
              theme={theme}
            >
              <StatusIcon
                alerts={alerts}
                status={hostStatusStatus}
              />
            </StatusBadge>
          ) : (
            <StatusIcon
              alerts={alerts}
              status={hostStatusStatus}
            />
          )}
        </div>
      )}
      popoverContents={
        <StatusPopoverContent
          title={statusConfig[hostStatusStatus].title}
          alerts={hideAlerts ? [] : alerts}
        />
      }
      anchorOrigin={{
        vertical: "top",
        horizontal: "right"
      }}
    />
  );
}
